@@ -9,7 +9,8 @@ Hornet 4 Drive, 21.4,   6, 259.0, 110, 3.08, 3.215,  1,  0
      Mazda RX4, 21.0,   6, 160.0, 110, 3.90, 2.620,  0,  1
        Valiant, 18.1,   6, 225.0, 105, 2.76, 3.460,  1,  0
       Merc 280, 19.2,   6, 167.6, 123, 3.92, 3.440,  1,  0
-", stringsAsFactors = FALSE, strip.white = TRUE)
+", stringsAsFactors = FALSE, strip.white = TRUE) %>%
+  as_tibble()
 
 example_df_b <- read.csv(text = "
             car,    wt,  mpg,  hp, cyl,  disp, carb, drat, vs
@@ -23,4 +24,5 @@ example_df_b <- read.csv(text = "
      Merc 450SE, 4.070, 16.4, 180,   8, 275.8,    3, 3.07,  0
        Merc 230, 3.150, 22.8,  95,   4, 140.8,    2, 3.92,  1
   Mazda RX4 Wag, 2.875, 21.0, 110,   6, 160.0,    4, 3.90,  0
-", stringsAsFactors = FALSE, strip.white = TRUE)
+", stringsAsFactors = FALSE, strip.white = TRUE) %>%
+  as_tibble()
