@@ -110,6 +110,13 @@ test_that("Error when `by` uses `join_by`", {
   expect_snapshot(compare(a, b, by = join_by(x)), error = TRUE)
 })
 
+test_that("Error when table_id is not as expected", {
+  a <- data.frame(x = 1)
+  b <- data.frame(x = 1)
+  expect_snapshot(compare(a, b, by = x, table_id = c("a", "b", "c")), error = TRUE)
+  expect_snapshot(compare(a, b, by = x, table_id = 1:2), error = TRUE)
+})
+
 test_that("Error on different classes with coerce = FALSE", {
   expect_snapshot(
     compare(test_df_a, test_df_b, by = car, coerce = FALSE),
@@ -128,6 +135,19 @@ test_that("example comparison", {
   expect_snapshot(comp)
 })
 
+test_that("example comparison with custom `table_id`", {
+  expect_snapshot(
+    compare(test_df_a, test_df_b, by = car, table_id = c("orignal", "updated"))
+  )
+})
+
+test_that("example comparison with `table_id` which is not a universal name", {
+  expect_snapshot(
+    comp <- compare(test_df_a, test_df_b, by = car, table_id = c("first result", "new"))
+  )
+  expect_snapshot(comp)
+})
+
 test_that("allow_bothNA works", {
   comp <- compare(
     tibble(x = 1, y = NA),
@@ -232,12 +252,12 @@ test_that("versus.copy_data_table option works", {
 
 test_that("locate_matches() handles unmatched rows correctly", {
   # all common
-  expect_snapshot(locate_matches(tibble(x = 1), tibble(x = 1), by = 'x'))
+  expect_snapshot(locate_matches(tibble(x = 1), tibble(x = 1), by = "x"))
   # all different
-  expect_snapshot(locate_matches(tibble(x = 1), tibble(x = 2), by = 'x'))
+  expect_snapshot(locate_matches(tibble(x = 1), tibble(x = 2), by = "x"))
   # some different in each table
-  expect_snapshot(locate_matches(tibble(x = 1:2), tibble(x = 2:3), by = 'x'))
+  expect_snapshot(locate_matches(tibble(x = 1:2), tibble(x = 2:3), by = "x"))
   # some different in only one table
-  expect_snapshot(locate_matches(tibble(x = 1:2), tibble(x = 2), by = 'x'))
-  expect_snapshot(locate_matches(tibble(x = 2), tibble(x = 1:2), by = 'x'))
+  expect_snapshot(locate_matches(tibble(x = 1:2), tibble(x = 2), by = "x"))
+  expect_snapshot(locate_matches(tibble(x = 2), tibble(x = 1:2), by = "x"))
 })
